//	ColourChooser.cpp - Simple colour chooser window.
//	----------------------------------------------------------------------------
//	This file is part of Motion Composition Tool, a simple application for
//	creating simple abstract animations.
//	Copyright (c) 2007 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#include "ColourChooser.h"
#include "Window.h"

#include <iostream>

using namespace std;

//------------------------------------------------------------------------------
ColourChooser::ColourChooser(Window *parentComp, int col):
Component(),
parent(parentComp),
colour(col),
retval(false)
{
	addAndMakeVisible(colourSelector = new ColourSelector());
	colourSelector->addChangeListener(this);
	colourSelector->setCurrentColour(parent->getPolygonColour(col));
	addAndMakeVisible(cancel = new TextButton(T("Cancel")));
	cancel->addButtonListener(this);
	addAndMakeVisible(ok = new TextButton(T("Ok")));
	ok->addButtonListener(this);

	setSize(400, 400);
}

//------------------------------------------------------------------------------
ColourChooser::~ColourChooser()
{
	deleteAllChildren();
}

//------------------------------------------------------------------------------
void ColourChooser::resized()
{
	colourSelector->setBounds(0, 0, getWidth(), getHeight()-35);
	cancel->setBounds(50, (getHeight()-30), 75, 25);
	ok->setBounds((getWidth()-125), (getHeight()-30), 75, 25);
}

//------------------------------------------------------------------------------
void ColourChooser::buttonClicked(Button *button)
{
	if(button == cancel)
	{
		retval = false;
		getParentComponent()->exitModalState(false);
	}
	else
	{
		retval = true;
		getParentComponent()->exitModalState(true);
	}
}

//------------------------------------------------------------------------------
void ColourChooser::changeListenerCallback(void *object)
{
	if(object == colourSelector)
		parent->setPolygonColour(colour, colourSelector->getCurrentColour());
}
