//	app.cpp - Main application stuff.
//	----------------------------------------------------------------------------
//	This file is part of Motion Composition Tool, a simple application for
//	creating simple abstract animations.
//	Copyright (c) 2007 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#include <juce.h>
#include "app.h"
#include "Window.h"

//------------------------------------------------------------------------------
void App::initialise(const String& commandLine)
{
	Window *tempComp;

	LookAndFeel::setDefaultLookAndFeel(shiny = new ShinyLookAndFeel());

	commands = new ApplicationCommandManager();

	win = new DocumentWindow(T("Motion Composition Tool"),
						   Colours::lightblue,
						   DocumentWindow::allButtons);

	win->setContentComponent(tempComp = new Window());
	win->getCloseButton()->addButtonListener(this);
	win->setMenuBar(tempComp, commands);
	win->centreWithSize(800, 640);
	win->setVisible(true);
}

//------------------------------------------------------------------------------
void App::shutdown()
{
	delete win;
	delete shiny;
	delete commands;
}

//------------------------------------------------------------------------------
void App::buttonClicked(Button *button)
{
	JUCEApplication::quit();
}

START_JUCE_APPLICATION(App)
